package cokr.xit.fims.cmmn.dao;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import cokr.xit.fims.cmmn.OtptArtclStng;
import cokr.xit.fims.cmmn.OtptForm;
import cokr.xit.fims.cmmn.OtptStngQuery;
import cokr.xit.foundation.component.AbstractMapper;
import cokr.xit.foundation.data.DataObject;

@Mapper("otptStngMapper")
public interface OtptStngMapper extends AbstractMapper {

	/**지정한 조건에 따라 출력물 전역 설정을 조회한다.<br />
	 * @param query 출력물 설정 조회 조건
	 * @return 출력물 전역 설정
	 */
	DataObject selectOtptBscStng(OtptStngQuery otptStngQuery);

	int insertBscStng(OtptForm otptForm);

	int updateBscStng(OtptForm otptForm);

	/**지정한 조건에 따라 출력 항목 설정을 조회한다.<br />
	 * @param query 출력물 설정 조회 조건
	 * @return 출력물 설정 항목
	 */
	List<DataObject> selectOtptArtclStngList(OtptStngQuery query);

	int updateArtclStng(OtptArtclStng update);

	int deleteArtclStng(OtptForm otptForm);

	int insertArtclStng(OtptArtclStng insert);
}